@@ -49,6 +49,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 '''
 
+import os
 import sys
 from . import LOG
 
@@ -79,7 +80,13 @@ class Gui(Gtk.Window):
             ("gtk-harddisk", _("Installed Software"), "inst"),
             ("applications-other", _("Apps Basket"), "basket")
         ]
-        self.toolbar = toolbar.Toolbar()
+
+        if os.environ.get('XDG_CURRENT_DESKTOP') == 'GNOME':
+            self.toolbar = toolbar.Headerbar()
+            self.set_titlebar(self.toolbar)
+        else:
+            self.toolbar = toolbar.Toolbar()
+
         self.pages.sections = self.toolbar.add_sections(
             self.sections, True, self.pages.change_section)
         self.categories_button_dict = self.pages.categories.append_sections(
@@ -94,9 +101,11 @@ class Gui(Gtk.Window):
         self.search_pkg = self.toolbar.entry
         self.vbox = Gtk.VBox()
         self.vbox1 = Gtk.VBox()
-        #self.vbox1.set_border_width(5)
-        #self.vbox1.set_spacing(5)
-        self.vbox.pack_start(self.toolbar, False, False, 0)
+
+        if os.environ.get('XDG_CURRENT_DESKTOP') != 'GNOME':
+            self.vbox.pack_start(self.toolbar, False, False, 0)
+        else:
+            self.vbox.pack_start(self.toolbar.searchbar, False, False, 0)
         self.vbox.pack_start(self.vbox1, True, True, 0)
         self.vbox1.pack_start(self.statusbox, False, False, 0)
         self.vbox1.pack_start(self.pages, True, True, 0)
